@@ -1,9 +1,9 @@
 #define WILDMIDI_CFG "wildmidi.cfg"
 
-#define PACKAGE_URL "http://www.mindwerks.net/projects/wildmidi/"
+#define PACKAGE_URL "https://github.com/Mindwerks/wildmidi"
 #define PACKAGE_BUGREPORT "https://github.com/Mindwerks/wildmidi/issues"
 
-#define PACKAGE_VERSION "0.4.3"
+#define PACKAGE_VERSION "0.4.6"
 
 #define HAVE_C_INLINE
 
@@ -20,3 +20,7 @@
 
 #define HAVE_STDINT_H 1
 #define HAVE_INTTYPES_H 1
+
+/* #undef AUDIODRV_OPENAL */
+#define AUDIODRV_COREAUDIO 1
+
